WorkerSpawnException class final

A worker failed to spawn or never reported ready.

Implemented types

Constructors

WorkerSpawnException(String message, {Object? cause})
Creates the exception with a human-readable message.

Properties

cause Object?
The underlying error, when one was captured.
final
hashCode int
The hash code for this object.
no setterinherited
message String
What went wrong.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited