WorkerSpawnException class final
A worker failed to spawn or never reported ready.
- Implemented types
Constructors
- WorkerSpawnException(String message, {Object? cause})
-
Creates the exception with a human-readable
message.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited